@@ -6,7 +6,8 @@ from datetime import datetime, timedelta
 import pandas as pd
 from notecoin.base.database.lanzou import LanzouDirectory
 from notecoin.coins.base.load import LoadDataKline, LoadTradeKline
-from notecoin.utils.time import day_during, month_during, week_during, year_during
+from notecoin.utils.time import (day_during, month_during, week_during,
+                                 year_during)
 from notefile.compress import tarfile
 
 logger = logging.getLogger()
@@ -111,7 +112,8 @@ class DataFileProperty:
         exchan.table.delete_all()
         unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
         # 下载
-        exchan.load_all(timeframe=file_pro.timeframe, unix_start=unix_start, unix_end=unix_end)
+        exchan.load_all(timeframe=file_pro.timeframe, unix_start=unix_start,
+                        unix_end=unix_end, csv_path=file_pro.file_path_csv())
         # 保存
         exchan.table.to_csv_all(file_pro.file_path_csv(), page_size=100000)
         # 压缩
