@@ -1,3 +1,4 @@
+import csv
 import json
 import logging
 import time
@@ -6,7 +7,7 @@ from datetime import datetime
 import ccxt  # noqa: E402
 import pandas as pd
 from ccxt.base.exchange import Exchange
-from notecoin.base.database import KlineData, TradeData
+from notecoin.base.database import KlineData
 from tqdm import tqdm
 
 logger = logging.getLogger()
@@ -54,7 +55,7 @@ class LoadDataKline:
         unix_end = unix_end
         unix_max = unix_max or unix_end
         unix_min = unix_min or unix_end
-        # print(unix_start, unix_end, unix_max, unix_max)
+
         if abs((unix_max - unix_min) / unix_delta) > 100:
             if unix_min >= unix_start:
                 unix_temp = unix_min
@@ -93,60 +94,25 @@ class LoadDataKline:
 
 
 class LoadTradeKline:
-    def __init__(self, exchange: Exchange, suffix="com", *args, **kwargs):
-        self.table = TradeData(prefix=exchange.name, suffix=suffix)
+    def __init__(self, exchange: Exchange, csv_path='trade.csv', *args, **kwargs):
         self.exchange = exchange
+        self.csv_path = csv_path
+        self.csv_writer = None
         super(LoadTradeKline, self).__init__(*args, **kwargs)
 
     def load_all(self, *args, **kwargs):
         self.exchange.load_markets()
-        pbr = tqdm(self.exchange.symbols)
-        for sym in pbr:
-            if ':' not in sym:
-                pbr.set_description(sym)
-                self.load(sym, *args, **kwargs)
+        with open(self.csv_path, mode="w") as csv_f:
+            csv_writer = csv.DictWriter(csv_f, delimiter=",",
+                                        fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+            csv_writer.writeheader()
+            pbr = tqdm(self.exchange.symbols)
+            for sym in pbr:
+                if ':' not in sym:
+                    pbr.set_description(sym)
+                    self.load(sym, csv_writer=csv_writer, *args, **kwargs)
 
-    def load_bak(self, symbol, unix_start, unix_end, *args, **kwargs):
-        one_hour = 3600 * 1000
-        since = unix_start
-        previous_trade_id = None
-        while since < unix_end:
-            try:
-                params = {
-                    'end_time': int(end_time / 1000),
-                }
-                trades = self.exchange.fetch_trades(symbol, since, limit=1000)
-
-                if len(trades) == 0:
-                    since += one_hour
-                    continue
-
-                last_trade = trades[-1]
-                if previous_trade_id == last_trade['id']:
-                    since += one_hour
-                    continue
-
-                since = last_trade['timestamp']
-                previous_trade_id = last_trade['id']
-
-                result = []
-                for trade in trades:
-                    result.append({
-                        'symbol': trade['symbol'],
-                        'id': trade['id'],
-                        'timestamp': trade['timestamp'],
-                        'type': trade['type'],
-                        'side': trade['side'],
-                        'price': trade['price'],
-                        'amount': trade['amount'],
-                    })
-                self.table.insert(result)
-                time.sleep(int(self.exchange.rateLimit / 1000))
-            except ccxt.NetworkError as e:
-                print(type(e).__name__, str(e))
-                self.exchange.sleep(10000)
-
-    def load(self, symbol, unix_start, unix_end, *args, **kwargs):
+    def load(self, symbol, unix_start, unix_end, csv_writer, *args, **kwargs):
         since = unix_start
         previous_trade_id = None
         result = []
@@ -162,9 +128,10 @@ class LoadTradeKline:
                     continue
                 since = last_trade['timestamp']
                 previous_trade_id = last_trade['id']
+
                 result.extend([{
                     'symbol': trade['symbol'],
-                    'id': trade['id'],
+                    'id': trade['id'].replace('\n', ''),
                     'timestamp': trade['timestamp'],
                     'type': trade['type'],
                     'side': trade['side'],
@@ -174,10 +141,10 @@ class LoadTradeKline:
 
                 time.sleep(int(self.exchange.rateLimit / 1000))
                 if len(result) > 30000:
-                    self.table.insert(result)
+                    csv_writer.writerows(result)
                     result.clear()
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
         if len(result) > 0:
-            self.table.insert(result)
+            csv_writer.writerows(result)
